use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007006
use Test::Spelling 0.17;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
API
Alders
Author
Autocomplete
BBYRD
Christian
Distribution
Etheridge
Favorite
File
Graham
Karen
Knop
Logan
MetaCPAN
Mickey
Module
Olaf
POD
Rating
Release
Sawyer
SineSwiper
Source
Walde
ether
github
haarg
lib
loganbell
mickey75
olaf
reneeb
walde
xsawyerx
